/* Copyright (C) 2003-2005 Tresys Technology, LLC
 * see file 'COPYING' for use and warranty information */

/*
 * Author: Karl MacMillan <kmacmillan@tresys.com>
 */

#ifndef QUERY_WINDOW_H
#define QUERY_WINDOW_H

int query_window_create(int *tree_item_idx);

#endif
